diagCharAA returns a list, where each entry belongs to one
taxon of interest. Each taxon of interest has a set of diagnostic
molecular characters (position, type, characteristic states for taxon of
interest, compared taxa) assigned to it.
type1 means that the character is suitable to distinguish each
individual of the taxon of interest from all individuals of the remaining
taxa, and that it is fixed for one state in the taxon of interest.
type2 means that the character is suitable to distinguish each
individual of the taxon of interest from all individuals of the remaining
taxa, and that it is not fixed for one state in the taxon of interest.
type3 means that the character is suitable to distinguish some (but
not all) individuals of the taxon of interest from all individuals of the
remaining taxa.
type4 means that the character is suitable to distinguish each
individual of the taxon of interest from all individuals of at least one
(but not all) other taxon while being fixed in both the taxon of interest
and the compared taxa.
diagCharAA returns for each taxon of interest the following elements:
positionThe positions of its diagnostic molecular characters.
typeThe types of the diagnostic molecular characters.
statesThe states that are characteristic for the taxon i of interest,
i.e. states that are distinct from "X" and unique to the taxon of interest
(in case of type 1, 2 or 3), or fixed in the taxon of interest (type 4), resp.
compared taxaOnly relevant for type 4 characters. It contains the
name x if the character is found to be a type 4 character of the taxon of
interest when being compared to taxon x.